@@ -34,7 +34,7 @@ advancetoken(FILE *flib, char delimiter)
     char *lineptr = linepos;
     char *lptr, *tptr;
     char *result;
-    int commentblock, concat, nest;
+    int commentblock, concat, nest, quoted;
 
     commentblock = 0;
     concat = 0;
@@ -148,12 +148,17 @@ advancetoken(FILE *flib, char delimiter)
     while (isspace(*lineptr)) lineptr++;
     linepos = lineptr;
 
-    // Final:  Remove trailing whitespace
+    // Remove any trailing whitespace
     tptr = token + strlen(token) - 1;
     while (isspace(*tptr)) {
 	*tptr = '\0';
 	tptr--;
     }
+    // Final:  Remove any surrounding quotes
+    if ((*token == '\"') && (*tptr == '\"') && (token != tptr)) {
+	*tptr = '\0';
+	memmove(token, token + 1, strlen(token));
+    }
     return token;
 }
 
